pyLBM.elements.Ellipse
======================

.. currentmodule:: pyLBM.elements

.. autoclass:: Ellipse

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Ellipse.distance
         Ellipse.get_bounds
         Ellipse.point_inside
         Ellipse.test_label



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Ellipse.number_of_bounds

